@@ -2,11 +2,13 @@
 
 import sys
 import os
+import datetime
 
-sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../build")
+sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)) + "/../build")
 
 from pywpsrpc.rpcwppapi import wppapi
 from pywpsrpc import (rpcwppapi, common)
+from pywpsrpc.utils import RpcIter
 
 
 def check_call(funcName, hr, value=None):
@@ -41,6 +43,24 @@ def test():
     hr, name = pres.get_FullName()
     check_call("pres.get_FullName", hr, name)
 
+    props = pres.CustomDocumentProperties
+    print("Doc Props:")
+    for prop in RpcIter(props):
+        print("\t %s: %s" % (prop.Name, prop.Value))
+
+    a_date = datetime.date(2020, 7, 20)
+    hr, prop = props.Add("_a_date", False, Value=a_date)
+    assert(hr == common.S_OK and prop.Value.date() == a_date)
+
+    a_datetime = datetime.datetime(2020, 7, 21, 14, 15, 30)
+    hr, prop = props.Add("_a_datetime", False, Value=a_datetime)
+    assert(hr == common.S_OK and prop.Value == a_datetime)
+
+    props = pres.BuiltInDocumentProperties
+    print("Builtin Props:")
+    for prop in RpcIter(props):
+        print("\t %s: %s" % (prop.Name, prop.Value))
+
     hr = pres.Close()
     check_call("pres.Close", hr)
 
